# ChemistryAi

Github

- https://github.com/infinity390/chemistryai

ChemistryAi is a simple Python library for:

- Parsing SMILES strings into graph structures.
- Generating IUPAC names for acyclic and cyclic hydrocarbon compounds.
- Visualizing molecules with RDKit.

## Installation

```bash
pip install rdkit-pypi
pip install .
